@@ -1,13 +1,13 @@
-# Copyrights 2010 by Mark Overmeer.
+# Copyrights 2010-2012 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.00.
 use warnings;
 use strict;
 
 package XML::eXistDB::RPC;
 use vars '$VERSION';
-$VERSION = '0.11';
+$VERSION = '0.12';
 
 
 use Log::Report 'xml-existdb', syntax => 'LONG';
@@ -473,19 +473,16 @@ sub uploadDocument($$@)
     my $compr  = exists $args{compress} ? $args{compress} : $args{compr_upload};
     for ($chunks, $compr) { $_ *= 1024 if defined $_ } 
 
-    my @dates  = _date_options $args{creation_date}, $args{modify_date};
-    my $replace= $args{replace};
-    my $mime   = $args{mime_type} || 'text/xml';
-
-    my $to_sent = length $doc;
-    return $self->parse($doc, $resource, $replace, @dates)  # simple file
-        if $to_sent < $chunks;
+    my @dates   = _date_options $args{creation_date}, $args{modify_date};
+    my $replace = $args{replace};
+    my $mime    = $args{mime_type} || 'text/xml';
 
     # Send file in chunks
-    my $sent = 0;
+    my $to_sent = length $doc;
+    my $sent    = 0;
     my $tmp;
 
-    while($sent + $chunks <= $to_sent)
+    while($sent < $to_sent)
     {   (my $rc, $tmp) = $self->upload($tmp, substr($doc, $sent, $chunks));
         $rc==0 or return ($rc, $tmp);
         $sent += $chunks;
@@ -825,9 +822,9 @@ sub parseLocalExt($$$$;$$)
 
 sub upload($;$)
 {   my $self = shift;
-    my $tmp  = @_ == 3 ? shift : undef;
-    $self->{rpc}->upload((defined $tmp ? (string => $tmp) : ())
-       , string => $_[3], int => length($_[3]));
+    my $tmp  = @_ == 2 ? shift : undef;
+    $self->{rpc}->upload(string => (defined $tmp ? $tmp : '')
+       , base64 => $_[0], int => length($_[0]));
 }
 
 
